Core types, traits, and utilities for ccstat
This crate provides the foundational types, error handling, timezone configuration, filters, and utility modules used by all other ccstat crates.
Re-exports
pub use error::CcstatError;pub use error::Result;pub use types::CostMode;pub use types::DailyDate;pub use types::ISOTimestamp;pub use types::ModelName;pub use types::SessionId;pub use types::TokenCounts;
Modules
- aggregation_
types - Aggregation data types for ccstat
- error
- Error types for ccstat
- filters
- Filtering module for usage entries
- memory_
pool - Memory pool for efficient allocation during parsing
- model_
formatter - Model name formatting module for ccstat
- provider
- Provider trait for data loaders
- string_
pool - String interning for memory optimization
- timezone
- Timezone utilities for date handling
- types
- Core domain types for ccstat