Module string_pool

Module string_pool 

String interning for memory optimization

This module provides string interning capabilities to reduce memory usage when dealing with repeated strings like model names and session IDs.

Structs

InternedModel
Interned model name
InternedSession
Interned session ID
InternerStats
Statistics about string interning